Level 7 b: Custom template engine
================================================================================

We will test this on '-pd' cli option with custom template engine.

.. code-block:: bash

   $ moban --template-type de-duplicate -pd custom-plugin -t duplicated_content.txt 
